@@ -84,6 +84,7 @@ _DEFAULTS = {
     "CELERY_EVENT_EXCHANGE": "celeryevent",
     "CELERY_EVENT_EXCHANGE_TYPE": "direct",
     "CELERY_EVENT_ROUTING_KEY": "celeryevent",
+    "CELERY_EVENT_PERSISTENT": True,
     "CELERY_EVENT_SERIALIZER": "json",
     "CELERY_RESULT_EXCHANGE": "celeryresults",
     "CELERY_RESULT_EXCHANGE_TYPE": "direct",
@@ -247,6 +248,7 @@ def prepare(m, source=settings, defaults=_DEFAULTS):
     m.EVENT_EXCHANGE = _get("CELERY_EVENT_EXCHANGE")
     m.EVENT_EXCHANGE_TYPE = _get("CELERY_EVENT_EXCHANGE_TYPE")
     m.EVENT_ROUTING_KEY = _get("CELERY_EVENT_ROUTING_KEY")
+    m.EVENT_PERSISTENT = _get("CELERY_EVENT_PERSISTENT")
     m.EVENT_SERIALIZER = _get("CELERY_EVENT_SERIALIZER")
 
     # :--- AMQP Backend settings                    <-   --   --- - ----- -- #
