@@ -2,7 +2,6 @@ import socket
 import unittest2 as unittest
 
 from datetime import datetime, timedelta
-from multiprocessing import get_logger
 from Queue import Empty
 
 from carrot.backends.base import BaseMessage
@@ -10,6 +9,7 @@ from carrot.connection import BrokerConnection
 from celery.utils.timer2 import Timer
 
 from celery import conf
+from celery import log
 from celery.decorators import task as task_dec
 from celery.decorators import periodic_task as periodic_task_dec
 from celery.serialization import pickle
@@ -17,6 +17,7 @@ from celery.utils import gen_unique_id
 from celery.worker import WorkController
 from celery.worker.buckets import FastQueue
 from celery.worker.job import TaskRequest
+from celery.worker import listener
 from celery.worker.listener import CarrotListener, QoS, RUN
 
 from celery.tests.compat import catch_warnings
@@ -154,7 +155,7 @@ class test_QoS(unittest.TestCase):
 
     def test_decrement(self):
         consumer = self.MockConsumer()
-        qos = QoS(consumer, 10, get_logger())
+        qos = QoS(consumer, 10, log.get_default_logger())
         qos.update()
         self.assertEqual(int(qos.value), 10)
         self.assertEqual(consumer.prefetch_count, 10)
@@ -171,7 +172,7 @@ class test_CarrotListener(unittest.TestCase):
     def setUp(self):
         self.ready_queue = FastQueue()
         self.eta_schedule = Timer()
-        self.logger = get_logger()
+        self.logger = log.get_default_logger()
         self.logger.setLevel(0)
 
     def tearDown(self):
@@ -279,6 +280,31 @@ class test_CarrotListener(unittest.TestCase):
         context = catch_warnings(record=True)
         execute_context(context, with_catch_warnings)
 
+    def test_receive_message_eta_OverflowError(self):
+        l = MyCarrotListener(self.ready_queue, self.eta_schedule, self.logger,
+                             send_events=False)
+        backend = MockBackend()
+        called = [False]
+
+        def to_timestamp(d):
+            called[0] = True
+            raise OverflowError()
+
+        m = create_message(backend, task=foo_task.name,
+                                    args=("2, 2"),
+                                    kwargs={},
+                                    eta=datetime.now().isoformat())
+        l.event_dispatcher = MockEventDispatcher()
+        l.control_dispatch = MockControlDispatch()
+
+        prev, listener.to_timestamp = listener.to_timestamp, to_timestamp
+        try:
+            l.receive_message(m.decode(), m)
+            self.assertTrue(m.acknowledged)
+            self.assertTrue(called[0])
+        finally:
+            listener.to_timestamp = prev
+
     def test_receive_message_InvalidTaskError(self):
         logger = MockLogger()
         l = MyCarrotListener(self.ready_queue, self.eta_schedule, logger,
@@ -336,7 +362,7 @@ class test_CarrotListener(unittest.TestCase):
                 self.prefetch_count_incremented = True
 
         l = MyCarrotListener(self.ready_queue, self.eta_schedule, self.logger,
-                           send_events=False)
+                             send_events=False)
         backend = MockBackend()
         m = create_message(backend, task=foo_task.name,
                            eta=datetime.now().isoformat(),
@@ -346,6 +372,7 @@ class test_CarrotListener(unittest.TestCase):
         l.qos = QoS(l.task_consumer, l.initial_prefetch_count, l.logger)
         l.event_dispatcher = MockEventDispatcher()
         l.receive_message(m.decode(), m)
+        l.eta_schedule.stop()
 
         items = [entry[2] for entry in self.eta_schedule.queue]
         found = 0
@@ -405,7 +432,7 @@ class test_CarrotListener(unittest.TestCase):
         self.assertTrue(dispatcher.flushed)
         l.event_dispatcher = MockEventDispatcher()
         l.receive_message(m.decode(), m)
-
+        l.eta_schedule.stop()
         in_hold = self.eta_schedule.queue[0]
         self.assertEqual(len(in_hold), 3)
         eta, priority, entry = in_hold
