@@ -42,6 +42,14 @@ def disable_events(panel):
     return {"ok": "events already disabled"}
 
 
+@Panel.register
+def heartbeat(panel):
+    panel.logger.info("Heartbeat requested by remote.")
+    dispatcher = panel.listener.event_dispatcher
+    if dispatcher.enabled:
+        dispatcher.send("worker-heartbeat")
+
+
 @Panel.register
 def set_loglevel(panel, loglevel=None):
     if loglevel is not None:
