@@ -1,3 +1,4 @@
+import logging
 import os
 import sys
 import time
@@ -10,13 +11,13 @@ from celery import log
 from celery import platforms
 from celery.datastructures import ExceptionInfo
 from celery.exceptions import SoftTimeLimitExceeded, TimeLimitExceeded
-from celery.exceptions import WorkerLostError
+from celery.exceptions import WorkerLostError, RetryTaskError
 from celery.execute.trace import TaskTrace
 from celery.loaders import current_loader
 from celery.registry import tasks
 from celery.utils import noop, kwdict, fun_takes_kwargs
 from celery.utils import truncate_text, maybe_iso8601
-from celery.utils.mail import mail_admins
+from celery.utils.compat import log_with_extra
 from celery.worker import state
 
 # pep8.py borks on a inline signature separator and
@@ -101,9 +102,10 @@ class WorkerTaskTrace(TaskTrace):
         """Execute, trace and store the result of the task."""
         self.loader.on_task_init(self.task_id, self.task)
         if self.task.track_started:
-            self.task.backend.mark_as_started(self.task_id,
-                                              pid=os.getpid(),
-                                              hostname=self.hostname)
+            if not self.task.ignore_result:
+                self.task.backend.mark_as_started(self.task_id,
+                                                  pid=os.getpid(),
+                                                  hostname=self.hostname)
         try:
             return super(WorkerTaskTrace, self).execute()
         finally:
@@ -121,7 +123,7 @@ class WorkerTaskTrace(TaskTrace):
         message, orig_exc = exc.args
         if self._store_errors:
             self.task.backend.mark_as_retry(self.task_id, orig_exc, strtb)
-        self.super.handle_retry(exc, type_, tb, strtb)
+        return self.super.handle_retry(exc, type_, tb, strtb)
 
     def handle_failure(self, exc, type_, tb, strtb):
         """Handle exception."""
@@ -197,13 +199,18 @@ class TaskRequest(object):
 
     """
     # Logging output
-    success_msg = "Task %(name)s[%(id)s] processed: %(return_value)s"
-    error_msg = """
+    success_msg = """\
+        Task %(name)s[%(id)s] succeeded in %(runtime)ss: %(return_value)s
+    """
+    error_msg = """\
         Task %(name)s[%(id)s] raised exception: %(exc)s\n%(traceback)s
     """
+    retry_msg = """\
+        Task %(name)s[%(id)s] retry: %(exc)s
+    """
 
     # E-mails
-    email_subject = """
+    email_subject = """\
         [celery@%(hostname)s] Error: Task %(name)s (%(id)s): %(exc)s
     """
     email_body = TASK_ERROR_EMAIL_BODY
@@ -371,7 +378,6 @@ class TaskRequest(object):
         self._set_executed_bit()
 
         args = self._get_tracer_args(loglevel, logfile)
-        self.time_start = time.time()
         result = pool.apply_async(execute_and_trace,
                                   args=args,
                                   kwargs={"hostname": self.hostname},
@@ -382,6 +388,8 @@ class TaskRequest(object):
         return result
 
     def on_accepted(self):
+        """Handler called when task is accepted by worker pool."""
+        self.time_start = time.time()
         state.task_accepted(self)
         if not self.task.acks_late:
             self.acknowledge()
@@ -400,7 +408,8 @@ class TaskRequest(object):
                 self.task_name, self.task_id))
             exc = TimeLimitExceeded()
 
-        self.task.backend.mark_as_failure(self.task_id, exc)
+        if self._store_errors:
+            self.task.backend.mark_as_failure(self.task_id, exc)
 
     def acknowledge(self):
         if not self.acknowledged:
@@ -422,7 +431,8 @@ class TaskRequest(object):
         msg = self.success_msg.strip() % {
                 "id": self.task_id,
                 "name": self.task_name,
-                "return_value": self.repr_result(ret_value)}
+                "return_value": self.repr_result(ret_value),
+                "runtime": runtime}
         self.logger.info(msg)
 
     def repr_result(self, result, maxlen=46):
@@ -430,6 +440,16 @@ class TaskRequest(object):
         #     "the quick brown fox jumps over the lazy dog" :)
         return truncate_text(repr(result), maxlen)
 
+    def on_retry(self, exc_info):
+        self.send_event("task-retried", uuid=self.task_id,
+                                        exception=repr(exc_info.exception.exc),
+                                        traceback=repr(exc_info.traceback))
+        msg = self.retry_msg.strip() % {
+                "id": self.task_id,
+                "name": self.task_name,
+                "exc": repr(exc_info.exception.exc)}
+        self.logger.info(msg)
+
     def on_failure(self, exc_info):
         """The handler used if the task raised an exception."""
         state.task_ready(self)
@@ -437,15 +457,19 @@ class TaskRequest(object):
         if self.task.acks_late:
             self.acknowledge()
 
-        self.send_event("task-failed", uuid=self.task_id,
-                                       exception=repr(exc_info.exception),
-                                       traceback=exc_info.traceback)
+        if isinstance(exc_info.exception, RetryTaskError):
+            return self.on_retry(exc_info)
 
         # This is a special case as the process would not have had
         # time to write the result.
         if isinstance(exc_info.exception, WorkerLostError):
-            self.task.backend.mark_as_failure(self.task_id,
-                                              exc_info.exception)
+            if self._store_errors:
+                self.task.backend.mark_as_failure(self.task_id,
+                                                  exc_info.exception)
+
+        self.send_event("task-failed", uuid=self.task_id,
+                                       exception=repr(exc_info.exception),
+                                       traceback=exc_info.traceback)
 
         context = {"hostname": self.hostname,
                    "id": self.task_id,
@@ -454,7 +478,13 @@ class TaskRequest(object):
                    "traceback": unicode(exc_info.traceback, 'utf-8'),
                    "args": self.args,
                    "kwargs": self.kwargs}
-        self.logger.error(self.error_msg.strip() % context)
+
+        log_with_extra(self.logger, logging.ERROR,
+                       self.error_msg.strip() % context,
+                       exc_info=exc_info,
+                       extra={"data": {"hostname": self.hostname,
+                                       "id": self.task_id,
+                                       "name": self.task_name}})
 
         task_obj = tasks.get(self.task_name, object)
         self.send_error_email(task_obj, context, exc_info.exception,
@@ -469,7 +499,8 @@ class TaskRequest(object):
                     return
             subject = self.email_subject.strip() % context
             body = self.email_body.strip() % context
-            return mail_admins(subject, body, fail_silently=fail_silently)
+            return current_loader().mail_admins(subject, body,
+                                                fail_silently=fail_silently)
 
     def __repr__(self):
         return '<%s: {name:"%s", id:"%s", args:"%s", kwargs:"%s"}>' % (
